"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const CPU6502_1 = require("../CPU6502");
const types_1 = require("../types");
// example instructions
// const I_NOOP = 0xEA;
const I_ORA = 0x0d;
const I_LDA = 0xa9;
const I_STA = 0x8d;
const I_JMP = 0x4c;
// set up memory
const ram = new Uint8ClampedArray(0xffff); // 64kb ram
ram.fill(0xea); // fill with noop instructions
ram[0xfffc] = 0x69; // store reset vector as 0269
ram[0xfffd] = 0x02;
// create a basic program
ram.set([
    // store 0x69 in address 0x0001
    I_LDA,
    0x69,
    I_STA,
    0x01,
    0x00,
    // set port b to output 0x55
    I_LDA,
    0x55,
    I_ORA,
    0x01,
    0x00,
    I_STA,
    0x00,
    0x60,
    // I_NOOP, I_NOOP, I_NOOP, // even out timing with the final jmp instruction
    // set port b to output 0xAA
    I_LDA,
    0xaa,
    I_STA,
    0x00,
    0x60,
    I_JMP,
    0x69,
    0x02,
], 0x0269);
const accessMemory = (readWrite, address, value) => {
    // capture a write to 0x6000 as a magic output address, print to console
    if (address === 0x6000 && readWrite === types_1.ReadWrite.write) {
        console.log("Output: ", value.toString(16));
        return;
    }
    if (readWrite === types_1.ReadWrite.read) {
        return ram[address];
    }
    ram[address] = value;
};
// @ts-ignore
const cpu = new CPU6502_1.CPU6502({
    accessMemory,
    logInstructions: true,
});
cpu.reset();
//# sourceMappingURL=2_test.js.map