"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const CPU6502_1 = require("../CPU6502");
const types_1 = require("../types");
const fs = require("fs-extra-promise");
// const ramImagePath = __dirname + "/../../programs/a.out";
const ramImagePath = __dirname + "/../../programs/c_test/a.out.c64";
async function run() {
    // set up memory
    const ram = new Uint8ClampedArray(0x10000); // 64kb ram
    // load binary code from disk
    const ramImage = await fs.readFileAsync(ramImagePath);
    ram.fill(0x00);
    ram.set(ramImage, 0x8000); // store program code in top half of memory
    const accessMemory = (readWrite, address, value) => {
        // capture a write to 0x6000 as a magic output address, print to console
        if (address === 0x6000 && readWrite === types_1.ReadWrite.write) {
            console.log(" Output: ", value, value.toString(16));
            return;
        }
        if (address === 0x6001 && readWrite === types_1.ReadWrite.write) {
            process.stdout.write(String.fromCharCode(value));
            return;
        }
        // capture a write to 0x6000 as a magic output address, pause program (exit)
        if (address === 0x6005 && readWrite === types_1.ReadWrite.write) {
            console.log("Exit captured! pausing clock");
            console.log(`${cpu.instructionsExecuted} instructions`);
            // console.log(Array.from(cpu.instructionsUsed).sort().join(";"));
            cpu.pauseClock();
            return;
        }
        if (readWrite === types_1.ReadWrite.read) {
            return ram[address];
        }
        ram[address] = value;
    };
    const cpu = new CPU6502_1.CPU6502({
        accessMemory,
    });
    cpu.reset();
}
run().catch(console.error);
//# sourceMappingURL=4_execute_c.js.map