import { CPU6502 } from "./CPU6502";
export declare enum ProcessorStatus {
    negative = 128,
    overflow = 64,
    const = 32,
    brk = 16,
    decimalMode = 8,
    disableIrqb = 4,
    zero = 2,
    carry = 1
}
export declare enum ClockMode {
    paused = 0,
    running = 1,
    waitForInterrupt = 2
}
export declare enum ReadWrite {
    read = 0,
    write = 1
}
export declare type AccessMemoryFunc = (readWrite: ReadWrite, address: number, value?: number) => number | void;
export interface CPUOperation {
    name: string;
    dataBytes: 0 | 1 | 2;
    func: (cpu: CPU6502, param: number) => void;
}
export interface CPUAddressingMode {
    dataBytes: 0 | 1 | 2;
    fetchValue: (cpu: CPU6502, param: number) => number;
    storeValue: (cpu: CPU6502, param: number, value: number) => void;
}
export declare type AddressingModeLabel = "#" | "a" | "zp" | "zp,x" | "zp,y" | "abs" | "abs,x" | "abs,y" | "(ind,x)" | "(ind),y";
export interface CPUOperationWithAddressingModes {
    name: string;
    addressingModes: {
        [key: number]: AddressingModeLabel;
    };
    func: (cpu: CPU6502, param: number) => void | number;
}
